@@ -21,7 +21,7 @@ stopifnot(all(
   , identical(Mode(NA), structure(NA_real_, freq = NA_integer_)) 
   , identical(Mode(c(NA, NA)), structure(NA_real_, freq = NA_integer_)) 
   , identical(Mode(c(NA, 0:5)), structure(NA_real_, freq = NA_integer_)) 
-  , identical(Mode(c(NA, 0:5), na.rm=TRUE), structure(NA_real_, freq = 1L)) 
+  , identical(Mode(c(NA, 0:5), na.rm=TRUE), structure(NA_real_, freq = NA_integer_)) 
   , identical(Mode(c(NA, 0:5, 5), na.rm=TRUE), structure(5, freq = 2L)) 
   , identical(Mode(c(0:5, 4, 5, 6)), structure(c(4, 5), freq = 2L)) 
   , identical(Mode(c(0:8, rep(c(1,3, 8), each=5))), structure(c(1, 3, 8), freq = 6L)) 
@@ -122,3 +122,20 @@ tx <- LogSt(x, base=2, threshold=6)
 x. <- LogStInv(tx)
 all.equal(x, x., tol = 0) # gave 0.15144. before bug fix
 stopifnot(all.equal(x, x., tol = 1e-14))
+
+
+# Test for correct using of weights in NormWeights() and Mean()
+AllIdentical(
+  Mean(x=c(0,2,4,6))
+  , Mean(x=c(0,2,4,6), na.rm=TRUE)
+  , Mean(x=c(0,2,4,6), zero.rm=TRUE)
+  , Mean(x=c(0,2,4,6), weights = rep(1, 4), zero.rm=TRUE)
+  , Mean(x=c(0,2,4,6), weights = rep(1, 4), na.rm=TRUE, zero.rm=TRUE)
+)
+
+
+
+
+
+
+
